## Tools

 - [Markdown Examples](docs/markdown/examples)
 - [Spelling and grammar](docs/tools/spelling-grammar-helper)
 - [GitHub guidance and support](docs/tools/github-helper)
 - [Portuguese as a programing language](docs/tools/portuguese-journalist)